from distutils.core import setup

setup(
name = 'aishvarya',
version = '1.0.2',
py_modules = ['aishvarya'],
author = 'aishvarya',
author_email = 'aishvarya.kumar@gmail.com',
url = 'https://pypi.org/project/aishvarya/',
description = 'A simple printer of nested lists',
)
